use serde::Serialize;

use super::footnote_definition::RenderRealFootnoteDefinition;
use super::GlobalSettings;
use super::PageHeader;
use super::RenderDocumentElement;

#[derive(Debug, Serialize)]
#[serde(tag = "type")]
#[serde(rename = "blog_post_page")]
pub(crate) struct RenderBlogPostPage {
    global_settings: GlobalSettings,

    page_header: Option<PageHeader>,

    /// The title that will be shown visibly on the page.
    title: Option<String>,

    self_link: Option<String>,

    children: Vec<RenderDocumentElement>,

    footnotes: Vec<RenderRealFootnoteDefinition>,
}

impl RenderBlogPostPage {
    // TODO: Maybe these settings should be moved into a common struct so this can have the same type signature as the others.
    pub(crate) fn new(
        global_settings: GlobalSettings,
        page_header: Option<PageHeader>,
        title: Option<String>,
        self_link: Option<String>,
        children: Vec<RenderDocumentElement>,
        footnotes: Vec<RenderRealFootnoteDefinition>,
    ) -> RenderBlogPostPage {
        RenderBlogPostPage {
            global_settings,
            page_header,
            title,
            self_link,
            children,
            footnotes,
        }
    }
}
